@@ -1,7 +1,8 @@
 package Config::Locale;
-BEGIN { $ENV{PERL_STRICTURES_EXTRA}=0 }
-use strictures 2;
-our $VERSION = '0.08';
+use 5.008001;
+use strict;
+use warnings;
+our $VERSION = '0.09';
 
 =head1 NAME
 
